<?php

namespace Litecms\Deal\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Deal\Actions\DealAction;
use Litecms\Deal\Http\Requests\DealActionRequest;
use Litecms\Deal\Http\Resources\DealResource;
use Litecms\Deal\Models\Deal;

/**
 * Admin web controller class.
 */
class DealActionController extends BaseController
{

    /**
     * Action controller function for deal.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(DealActionRequest $request, Deal $deal, $action)
    {
        try {
            $deal = DealAction::run($request, $deal, $action);

            $data = new DealResource($deal);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('deal::deal.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('deal/deal/' . $deal->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('deal/deal/' . $deal->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
