<?php

namespace Litecms\Deal\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Litecms\Deal\Actions\DealExim;
use Litecms\Deal\Http\Requests\DealEximRequest;

/**
 * Admin web controller class.
 */
class DealEximController extends BaseController
{
    /**
     * Action controller function for deal.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(DealEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = DealExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('deal:deal.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('deal/deal/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('deal/deal/' . $exim))
                ->redirect();
        }
    }
}
