<?php

namespace Litecms\Deal\Http\Controllers;

use Exception;
use Litecms\Deal\Actions\DealWorkflow;
use Litecms\Deal\Http\Requests\DealWorkflowRequest;
use Litecms\Deal\Http\Resources\DealResource;
use Litecms\Deal\Models\Deal;
use Litepie\Http\Controllers\ActionController as BaseController;

/**
 * Workflow controller class.
 *
 */
class DealWorkflowController extends BaseController
{
    /**
     * Action controller function for deal.
     *
     * @param Model $deal
     * @param action next action for the deal.
     *
     * @return Response
     */
    public function __invoke(DealWorkflowRequest $request, Deal $deal, $trasition)
    {
        try {
            $deal = DealWorkflow::run($request, $deal, $trasition);
            $data = new DealResource($deal);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('deal::deal.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('deal/deal/' . $deal->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('deal/deal/' . $deal->getRouteKey()))
                ->redirect();
        }
    }
}
